@@ -176,7 +176,7 @@ def manage_jobpool(jobdict, seed_names, seed_spec, weight_dir, tmp_path, cores,
     data = []
     for spec in jobdict:
         data.append([spec,
-                    {"weight_const": False, "seed_id": None, "query_id": None,
+                    {"weight_const": False, "seed_id": None, "query_id": None, "empty_as_1": False,
                      "priority_mode": True, "priority_threshold": 30, "max_cardinality": 500, "eFeature": 0.001,
                      "cores": 1, "eInstance": 0.01, "e_output": True, "feature_info": None,
                      "bidirectional": bidirectional, "raw": False, "silent": False, "reverse": False,
@@ -303,7 +303,7 @@ def write_phyloprofile(results, out_path, outname, groupdict):
 
 
 def get_options():
-    version = '1.12.3'
+    version = '1.14.0'
     parser = argparse.ArgumentParser(description='You are running FAS version ' + str(version) + '.',
                                      epilog="For more information on certain options, please refer to the wiki pages "
                                             "on github: https://github.com/BIONF/FAS/wiki")
